Module: RSpec::SleepingKingStudios::Deferred::Dsl
- Includes:
- ExampleConstants, ExampleGroups, Examples, Hooks, MemoizedHelpers, SharedExamples
- Defined in:
- lib/rspec/sleeping_king_studios/deferred/dsl.rb,
lib/rspec/sleeping_king_studios/deferred/dsl/hooks.rb,
lib/rspec/sleeping_king_studios/deferred/dsl/examples.rb,
lib/rspec/sleeping_king_studios/deferred/dsl/example_groups.rb,
lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb,
lib/rspec/sleeping_king_studios/deferred/dsl/memoized_helpers.rb,
lib/rspec/sleeping_king_studios/deferred/dsl/example_constants.rb
Overview
rubocop:disable Style/Documentation
Defined Under Namespace
Modules: ExampleConstants, ExampleGroups, Examples, Hooks, MemoizedHelpers, SharedExamples
Class Method Summary collapse
-
.extended(other) ⇒ Object
Callback invoked when the module is extended into another module or class.
Methods included from ExampleConstants
#example_class, #example_constant
Methods included from MemoizedHelpers
#call, #let, #let!, #let?, #subject, #subject!
Methods included from SharedExamples
#finclude_deferred, #finclude_examples, #fwrap_context, #fwrap_deferred, #fwrap_examples, #include_context, #include_deferred, #include_examples, #it_behaves_like, #it_should_behave_like, #shared_context, #shared_examples, #shared_examples_for, #wrap_context, #wrap_deferred, #wrap_examples, #xinclude_deferred, #xinclude_examples, #xwrap_context, #xwrap_deferred, #xwrap_examples
Methods included from SharedExamples::Macros
#define_included_examples_method, #define_shared_examples_method
Methods included from ExampleGroups
#context, #describe, #example_group, #fcontext, #fdescribe, #xcontext, #xdescribe
Methods included from ExampleGroups::Macros
Methods included from Examples
#example, #fexample, #fit, #focus, #fspecify, #it, #pending, #skip, #specify, #xexample, #xit, #xspecify
Methods included from Examples::Macros
Methods included from Hooks
#after, #append_after, #around, #before, #call, #deferred_hooks, #prepend_before
Class Method Details
.extended(other) ⇒ Object
Callback invoked when the module is extended into another module or class.
Delegates to child module #extended methods.
13 14 15 16 17 |
# File 'lib/rspec/sleeping_king_studios/deferred/dsl.rb', line 13 def self.extended(other) super other.extend(RSpec::SleepingKingStudios::Deferred::Dsl::MemoizedHelpers) end |