Module: RSpec::SleepingKingStudios::Deferred::Dsl::ExampleGroups

Extended by:
Macros
Included in:
RSpec::SleepingKingStudios::Deferred::Dsl
Defined in:
lib/rspec/sleeping_king_studios/deferred/dsl/example_groups.rb

Overview

Methods for defining deferred example groups.

Defined Under Namespace

Modules: Macros

Instance Method Summary collapse

Methods included from Macros

define_example_group_method

Instance Method Details

#context(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example group using the context method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example group's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example group. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example group.

  • block (Proc)

    the implementation of the example group.



47
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/example_groups.rb', line 47

define_example_group_method :context

#describe(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example group using the describe method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example group's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example group. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example group.

  • block (Proc)

    the implementation of the example group.



50
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/example_groups.rb', line 50

define_example_group_method :describe

#example_group(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example group using the example_group method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example group's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example group. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example group.

  • block (Proc)

    the implementation of the example group.



53
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/example_groups.rb', line 53

define_example_group_method :example_group

#fcontext(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example group using the fcontext method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example group's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example group. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example group.

  • block (Proc)

    the implementation of the example group.



56
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/example_groups.rb', line 56

define_example_group_method :fcontext

#fdescribe(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example group using the fdescribe method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example group's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example group. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example group.

  • block (Proc)

    the implementation of the example group.



59
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/example_groups.rb', line 59

define_example_group_method :fdescribe

#xcontext(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example group using the xcontext method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example group's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example group. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example group.

  • block (Proc)

    the implementation of the example group.



62
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/example_groups.rb', line 62

define_example_group_method :xcontext

#xdescribe(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example group using the xdescribe method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example group's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example group. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example group.

  • block (Proc)

    the implementation of the example group.



65
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/example_groups.rb', line 65

define_example_group_method :xdescribe