Module: RSpec::SleepingKingStudios::Deferred::Dsl::Examples

Extended by:
Macros
Included in:
RSpec::SleepingKingStudios::Deferred::Dsl
Defined in:
lib/rspec/sleeping_king_studios/deferred/dsl/examples.rb

Overview

Methods for defining deferred examples.

Defined Under Namespace

Modules: Macros

Instance Method Summary collapse

Methods included from Macros

define_example_method

Instance Method Details

#example(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example using the example method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example.

  • block (Proc)

    the implementation of the example.



47
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/examples.rb', line 47

define_example_method :example

#fexample(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example using the fexample method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example.

  • block (Proc)

    the implementation of the example.



50
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/examples.rb', line 50

define_example_method :fexample

#fit(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example using the fit method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example.

  • block (Proc)

    the implementation of the example.



53
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/examples.rb', line 53

define_example_method :fit

#focus(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example using the focus method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example.

  • block (Proc)

    the implementation of the example.



56
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/examples.rb', line 56

define_example_method :focus

#fspecify(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example using the fspecify method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example.

  • block (Proc)

    the implementation of the example.



59
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/examples.rb', line 59

define_example_method :fspecify

#it(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example using the it method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example.

  • block (Proc)

    the implementation of the example.



62
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/examples.rb', line 62

define_example_method :it

#pending(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example using the pending method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example.

  • block (Proc)

    the implementation of the example.



65
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/examples.rb', line 65

define_example_method :pending

#skip(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example using the skip method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example.

  • block (Proc)

    the implementation of the example.



68
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/examples.rb', line 68

define_example_method :skip

#specify(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example using the specify method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example.

  • block (Proc)

    the implementation of the example.



71
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/examples.rb', line 71

define_example_method :specify

#xexample(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example using the xexample method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example.

  • block (Proc)

    the implementation of the example.



74
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/examples.rb', line 74

define_example_method :xexample

#xit(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example using the xit method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example.

  • block (Proc)

    the implementation of the example.



77
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/examples.rb', line 77

define_example_method :xit

#xspecify(doc_string = nil, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred example using the xspecify method.

Parameters:

  • doc_string (String) (defaults to: nil)

    the example's doc string.

  • flags (Array<Symbol>)

    metadata flags for the example. Will be transformed into metadata entries with true values.

  • metadata (Hash)

    metadata for the example.

  • block (Proc)

    the implementation of the example.



80
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/examples.rb', line 80

define_example_method :xspecify