Module: RSpec::SleepingKingStudios::Deferred::Dsl::SharedExamples

Extended by:
Macros
Included in:
RSpec::SleepingKingStudios::Deferred::Dsl
Defined in:
lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb

Overview

Methods for defining and including deferred shared example groups.

Defined Under Namespace

Modules: Macros

Instance Method Summary collapse

Methods included from Macros

define_included_examples_method, define_shared_examples_method

Instance Method Details

#finclude_deferred(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred included example group using the finclude_deferred method.

Parameters:

  • name (String, Symbol, Module)

    the name for the included example group.

  • flags (Array<Symbol>)

    metadata flags for the included example group.

  • metadata (Hash)

    metadata for the included example group.

  • block (Proc)

    the implementation of the included example group.



82
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 82

define_included_examples_method :finclude_deferred

#finclude_examples(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred included example group using the finclude_examples method.

Parameters:

  • name (String, Symbol, Module)

    the name for the included example group.

  • flags (Array<Symbol>)

    metadata flags for the included example group.

  • metadata (Hash)

    metadata for the included example group.

  • block (Proc)

    the implementation of the included example group.



85
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 85

define_included_examples_method :finclude_examples

#fwrap_context(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred included example group using the fwrap_context method.

Parameters:

  • name (String, Symbol, Module)

    the name for the included example group.

  • flags (Array<Symbol>)

    metadata flags for the included example group.

  • metadata (Hash)

    metadata for the included example group.

  • block (Proc)

    the implementation of the included example group.



88
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 88

define_included_examples_method :fwrap_context

#fwrap_deferred(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred included example group using the fwrap_deferred method.

Parameters:

  • name (String, Symbol, Module)

    the name for the included example group.

  • flags (Array<Symbol>)

    metadata flags for the included example group.

  • metadata (Hash)

    metadata for the included example group.

  • block (Proc)

    the implementation of the included example group.



91
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 91

define_included_examples_method :fwrap_deferred

#fwrap_examples(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred included example group using the fwrap_examples method.

Parameters:

  • name (String, Symbol, Module)

    the name for the included example group.

  • flags (Array<Symbol>)

    metadata flags for the included example group.

  • metadata (Hash)

    metadata for the included example group.

  • block (Proc)

    the implementation of the included example group.



94
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 94

define_included_examples_method :fwrap_examples

#include_context(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred included example group using the include_context method.

Parameters:

  • name (String, Symbol, Module)

    the name for the included example group.

  • flags (Array<Symbol>)

    metadata flags for the included example group.

  • metadata (Hash)

    metadata for the included example group.

  • block (Proc)

    the implementation of the included example group.



97
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 97

define_included_examples_method :include_context

#include_deferred(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred included example group using the include_deferred method.

Parameters:

  • name (String, Symbol, Module)

    the name for the included example group.

  • flags (Array<Symbol>)

    metadata flags for the included example group.

  • metadata (Hash)

    metadata for the included example group.

  • block (Proc)

    the implementation of the included example group.



100
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 100

define_included_examples_method :include_deferred

#include_examples(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred included example group using the include_examples method.

Parameters:

  • name (String, Symbol, Module)

    the name for the included example group.

  • flags (Array<Symbol>)

    metadata flags for the included example group.

  • metadata (Hash)

    metadata for the included example group.

  • block (Proc)

    the implementation of the included example group.



103
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 103

define_included_examples_method :include_examples

#it_behaves_like(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred included example group using the it_behaves_like method.

Parameters:

  • name (String, Symbol, Module)

    the name for the included example group.

  • flags (Array<Symbol>)

    metadata flags for the included example group.

  • metadata (Hash)

    metadata for the included example group.

  • block (Proc)

    the implementation of the included example group.



106
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 106

define_included_examples_method :it_behaves_like

#it_should_behave_like(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred included example group using the it_should_behave_like method.

Parameters:

  • name (String, Symbol, Module)

    the name for the included example group.

  • flags (Array<Symbol>)

    metadata flags for the included example group.

  • metadata (Hash)

    metadata for the included example group.

  • block (Proc)

    the implementation of the included example group.



109
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 109

define_included_examples_method :it_should_behave_like

#shared_context(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred shared example group using the shared_context method.

Parameters:

  • name (String, Symbol, Module)

    the name for the shared example group.

  • flags (Array<Symbol>)

    metadata flags for the shared example group.

  • metadata (Hash)

    metadata for the shared example group.

  • block (Proc)

    the implementation of the shared example group.



112
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 112

define_shared_examples_method :shared_context

#shared_examples(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred shared example group using the shared_examples method.

Parameters:

  • name (String, Symbol, Module)

    the name for the shared example group.

  • flags (Array<Symbol>)

    metadata flags for the shared example group.

  • metadata (Hash)

    metadata for the shared example group.

  • block (Proc)

    the implementation of the shared example group.



115
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 115

define_shared_examples_method :shared_examples

#shared_examples_for(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred shared example group using the shared_examples_for method.

Parameters:

  • name (String, Symbol, Module)

    the name for the shared example group.

  • flags (Array<Symbol>)

    metadata flags for the shared example group.

  • metadata (Hash)

    metadata for the shared example group.

  • block (Proc)

    the implementation of the shared example group.



118
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 118

define_shared_examples_method :shared_examples_for

#wrap_context(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred included example group using the wrap_context method.

Parameters:

  • name (String, Symbol, Module)

    the name for the included example group.

  • flags (Array<Symbol>)

    metadata flags for the included example group.

  • metadata (Hash)

    metadata for the included example group.

  • block (Proc)

    the implementation of the included example group.



121
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 121

define_included_examples_method :wrap_context

#wrap_deferred(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred included example group using the wrap_deferred method.

Parameters:

  • name (String, Symbol, Module)

    the name for the included example group.

  • flags (Array<Symbol>)

    metadata flags for the included example group.

  • metadata (Hash)

    metadata for the included example group.

  • block (Proc)

    the implementation of the included example group.



124
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 124

define_included_examples_method :wrap_deferred

#wrap_examples(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred included example group using the wrap_examples method.

Parameters:

  • name (String, Symbol, Module)

    the name for the included example group.

  • flags (Array<Symbol>)

    metadata flags for the included example group.

  • metadata (Hash)

    metadata for the included example group.

  • block (Proc)

    the implementation of the included example group.



127
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 127

define_included_examples_method :wrap_examples

#xinclude_deferred(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred included example group using the xinclude_deferred method.

Parameters:

  • name (String, Symbol, Module)

    the name for the included example group.

  • flags (Array<Symbol>)

    metadata flags for the included example group.

  • metadata (Hash)

    metadata for the included example group.

  • block (Proc)

    the implementation of the included example group.



130
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 130

define_included_examples_method :xinclude_deferred

#xinclude_examples(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred included example group using the xinclude_examples method.

Parameters:

  • name (String, Symbol, Module)

    the name for the included example group.

  • flags (Array<Symbol>)

    metadata flags for the included example group.

  • metadata (Hash)

    metadata for the included example group.

  • block (Proc)

    the implementation of the included example group.



133
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 133

define_included_examples_method :xinclude_examples

#xwrap_context(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred included example group using the xwrap_context method.

Parameters:

  • name (String, Symbol, Module)

    the name for the included example group.

  • flags (Array<Symbol>)

    metadata flags for the included example group.

  • metadata (Hash)

    metadata for the included example group.

  • block (Proc)

    the implementation of the included example group.



136
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 136

define_included_examples_method :xwrap_context

#xwrap_deferred(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred included example group using the xwrap_deferred method.

Parameters:

  • name (String, Symbol, Module)

    the name for the included example group.

  • flags (Array<Symbol>)

    metadata flags for the included example group.

  • metadata (Hash)

    metadata for the included example group.

  • block (Proc)

    the implementation of the included example group.



139
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 139

define_included_examples_method :xwrap_deferred

#xwrap_examples(name, *flags, **metadata, &block) ⇒ void

This method returns an undefined value.

Defines a deferred included example group using the xwrap_examples method.

Parameters:

  • name (String, Symbol, Module)

    the name for the included example group.

  • flags (Array<Symbol>)

    metadata flags for the included example group.

  • metadata (Hash)

    metadata for the included example group.

  • block (Proc)

    the implementation of the included example group.



142
# File 'lib/rspec/sleeping_king_studios/deferred/dsl/shared_examples.rb', line 142

define_included_examples_method :xwrap_examples