Module: RSpec::SleepingKingStudios::Deferred::Examples

Defined in:
lib/rspec/sleeping_king_studios/deferred/examples.rb

Overview

Defines a deferred example group for declaring shared tests.

Defined Under Namespace

Modules: ClassMethods

Class Method Summary collapse

Class Method Details

.included(other) ⇒ Object

Callback invoked when the module is included in another module or class.

Extends the class or module with the Deferred::Definitions and Deferred::Examples::DSL modules.

Parameters:

  • other (Module)

    the other module or class.

See Also:



69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/rspec/sleeping_king_studios/deferred/examples.rb', line 69

def self.included(other)
  super

  other.extend  ClassMethods
  other.extend  RSpec::SleepingKingStudios::Deferred::Definitions
  other.extend  RSpec::SleepingKingStudios::Deferred::Dsl
  other.include RSpec::SleepingKingStudios::Deferred::Provider

  location = caller_locations(1, 1).first

  other.source_location = [location.path, location.lineno]
end